@@ -1,4 +1,4 @@
 # -*- coding: utf8 -*-
-from django.conf.urls import patterns, url, include
+from django.conf.urls import patterns
 
-urlpatterns = patterns('')
\ No newline at end of file
+urlpatterns = patterns('')
